@@ -156,26 +156,45 @@ linest.merMod <- function(object, L=NULL, conf.int=FALSE, conf.level=0.95, ...){
 .getLb2 <- function(L, bhat, VV, ddf.vec, is.est, level=0.95){
     off <- attr(L, "offset")
 
+    ## print(L)
+    ## print(VV)
+    notna <- !is.na(bhat)
     used       <- which(!is.na(bhat))
     bhat.used  <- bhat[used]
-    L   <- L[, used, drop=FALSE]
+    ## L   <- L[, used, drop=FALSE]
     res <- matrix(NA, nrow=nrow(L), ncol=3)
-    
+
+    ## print("ddddddddddddddddddddddd")
+    ## print(bhat)
+    ## cat("-------------\n")
     for (ii in 1:nrow(res)){
         kk <- L[ii,]
-        if (is.est[ii]){
+        ## print(kk)
+        ## kk <<- kk
+        ## bhat <<- bhat
+        zz <- kk[is.na(bhat)] ## values in kk for which beta is NA
+        ## print(zz)
+        if (length(zz) == 0)
+            is.zero <- TRUE
+        else
+            is.zero <- max(abs(zz)) < 1e-3
+
+        
+        ## print(is.zero)
+        if (is.est[ii] && is.zero){
+            kk   <- kk[used]
             est  <- sum(kk * bhat.used)
             se   <- sqrt(sum(kk * (VV %*% kk)))
             df2  <- ddf.vec[ii]
             res[ii,] <- c(est, se, df2)
         }
     }
-
+    
     if (!is.null(off))
         res[,1] <- res[,1] + off[[1]]
     
-    colnames(res) <- c("estimate","std.error","df") 
-    statistic        <- res[,"estimate"] / res[,"std.error"]
+    colnames(res) <- c("estimate", "std.error", "df") 
+    statistic     <- res[,"estimate"] / res[,"std.error"]
     res <- cbind(res[,1:2, drop=FALSE], statistic, df=res[,3])
 
     rownames(res) <- NULL
@@ -183,6 +202,58 @@ linest.merMod <- function(object, L=NULL, conf.int=FALSE, conf.level=0.95, ...){
     res
 }
 
+
+
+
+## .getLb2 <- function(L, bhat, VV, ddf.vec, is.est, level=0.95){
+##     off <- attr(L, "offset")
+
+##     used       <- which(!is.na(bhat))
+##     bhat.used  <- bhat[used]
+##     L   <- L[, used, drop=FALSE]
+##     res <- matrix(NA, nrow=nrow(L), ncol=3)
+    
+##     for (ii in 1:nrow(res)){
+##         kk <- L[ii,]
+##         if (is.est[ii]){
+##             est  <- sum(kk * bhat.used)
+##             se   <- sqrt(sum(kk * (VV %*% kk)))
+##             df2  <- ddf.vec[ii]
+##             res[ii,] <- c(est, se, df2)
+##         }
+##     }
+
+##     if (!is.null(off))
+##         res[,1] <- res[,1] + off[[1]]
+    
+##     colnames(res) <- c("estimate", "std.error", "df") 
+##     statistic        <- res[,"estimate"] / res[,"std.error"]
+##     res <- cbind(res[,1:2, drop=FALSE], statistic, df=res[,3])
+
+##     rownames(res) <- NULL
+##     ##print(res)
+##     res
+## }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 .ci_fun <- function (object, parm, level = 0.95, ...) 
 {
     ##object <- coef(object)
@@ -244,7 +315,7 @@ coef.linest_class <- function (object, ...) {
 
 #' @export
 print.linest_class <- function (x, ...){
-    cat("Coefficients:\n")
+    ## cat("Coefficients:\n")
     printCoefmat(x$coef)
 }
 
